derive_resolution_keys_with_context

Function derive_resolution_keys_with_context 

pub fn derive_resolution_keys_with_context(
    project: ProjectInstanceId,
    package: Option<&str>,
    graph: &SymbolGraph,
    context: ResolutionProjectionContext<'_>,
) -> Result<ResolutionKeyProjection, ResolutionProjectionError>
Derive bounded canonical keys with explicit repository module configuration.

Errors

Returns an error when a graph identity is invalid or one parser fact exceeds the bounded canonical-key fan-out.