extract_markdown_facts_controlled

Function extract_markdown_facts_controlled 

pub fn extract_markdown_facts_controlled(
    content: &str,
    control: &IndexWorkControl,
) -> Result<MarkdownFacts, IndexWorkFailure>
Extract Markdown facts while observing the shared indexing cancellation boundary.

Errors

Returns a typed cancellation or deadline failure without returning partial work.