extract_symbol_graph_controlled

Function extract_symbol_graph_controlled 

pub fn extract_symbol_graph_controlled(
    path: &str,
    language: Option<&str>,
    content: &str,
    control: &IndexWorkControl,
) -> Result<SymbolGraph, IndexWorkFailure>
Extract a symbol graph while observing the shared indexing cancellation boundary.

Errors

Returns a typed cancellation or deadline failure without returning a partial graph.