pub struct DocumentFact {
pub text: String,
pub locator: DocumentLocator,
pub line_start: usize,
pub line_end: usize,
}Expand description
One exact text fact retained from a supported document.
Fields
text: StringExtracted UTF-8 text for this fact.
locator: DocumentLocatorExact parser-relative locator for the text.
line_start: usizeOne-based first line in the emitted document text.
line_end: usizeOne-based last occupied line in the emitted document text.