pub struct DocumentFacts {
pub format: DocumentFormat,
pub text: String,
pub facts: Vec<DocumentFact>,
pub completeness: DocumentCompleteness,
pub provenance: DocumentParserProvenance,
}Expand description
Complete bounded text and provenance extracted from one document.
Fields
format: DocumentFormatFormat admitted by magic and language/extension checks.
text: StringExtracted text with preserved paragraph and run layout for the text index.
facts: Vec<DocumentFact>Exact text facts used to build graph evidence.
completeness: DocumentCompletenessWhether the supported part was fully examined.
provenance: DocumentParserProvenanceParser provenance for audit and graph evidence.
Implementations
Sourceimpl DocumentFacts
impl DocumentFacts
Sourcepub fn symbol_graph(&self, path: &str, language: Option<&str>) -> SymbolGraph
pub fn symbol_graph(&self, path: &str, language: Option<&str>) -> SymbolGraph
Project exact document facts into the existing sparse symbol graph.